%if 0%{?rhel} == 5
%define __python /usr/bin/python26
%endif

%if 0%{?rhel} <= 5
%{!?python_sitelib: %global python_sitelib %(%{__python} -c "from distutils.sysconfig import get_python_lib; print(get_python_lib())")}
BuildRoot: %{_tmppath}/%{name}-%{version}-%{release}-buildroot
%endif

%global srcname ansible

Name: ansible1.9
Summary: SSH-based configuration management, deployment, and task execution system
Version: 1.9.6
Release: 2%{?dist}

Group: Development/Libraries
License: GPLv3+
Source0: http://releases.ansible.com/ansible/%{srcname}-%{version}.tar.gz
# Left out of the release by mistake
Source1: CHANGELOG.md
# Patch to utilize a newer jinja2 package on epel6
# Non-upstreamable as it creates a dependency on a specific version of jinja.
# This is desirable for us as we have packages for that version but not for
# upstream as they don't know what their customers are running.
Patch100: ansible-newer-jinja.patch
Url: http://ansible.com
#
# Patch to detect dnf as package manager. 
# already upstream with https://github.com/opoplawski/ansible/commit/f624ec4cb8771736ffbe3fe81b2949edda159863
# https://bugzilla.redhat.com/show_bug.cgi?id=1258080
Patch0: ansible-1.9.3-dnf.patch
# Backport of the master branch dnf module. 
Patch2: ansible-dnf-backport.patch
BuildArch: noarch

%if 0%{?rhel} && 0%{?rhel} <= 5
BuildRequires: python26-devel

Requires: python26-PyYAML
Requires: python26-paramiko
Requires: python26-jinja2
Requires: python26-keyczar
Requires: python26-httplib2

%else

BuildRequires: python2-devel
BuildRequires: python-setuptools

%if (0%{?rhel} && 0%{?rhel} <= 6)
# Ansible will work with the jinja2 shipped with RHEL6 but users can gain
# additional jinja features by using the newer version
Requires: python-jinja2-26
%else
Requires: python-jinja2
%endif

Requires: PyYAML
Requires: python-paramiko
Requires: python-keyczar
Requires: python-httplib2
Requires: python-setuptools
Requires: python-six
Requires: sshpass
%endif

%if 0%{?rhel} == 6
# RHEL 6 needs a newer version of the pycrypto library for the ansible-vault
# command.  Note: If other pieces of ansible also grow to need pycrypto you may
# need to add: Requires: python-crypto or patch the other pieces of ansible to
# make use of this forward compat package (see the patch for ansible-vault
# above to see what needs to be done.)
Requires: python-crypto2.6
# The python-2.6 stdlib json module has a bug that affects the ansible
# to_nice_json filter
Requires: python-simplejson
%endif

# 
# This is needed to update the old ansible-firewall package that is no 
# longer needed. Note that you should also remove ansible-node-firewall manually
# Where you still have it installed. 
#
Provides: ansible-fireball = %{version}-%{release}
Obsoletes: ansible-fireball < 1.2.4

Provides: ansible = %{version}-%{release}
Conflicts: ansible

%description

Ansible is a radically simple model-driven configuration management,
multi-node deployment, and remote task execution system. Ansible works
over SSH and does not require any software or daemons to be installed
on remote nodes. Extension modules can be written in any language and
are transferred to managed machines automatically.

This package contains the older ansible-1.9.x package.  Some people will have
trouble upgrading from 1.9.x to 2.0 so providing ansible-1.9.x in this package
as an interim measure.

%prep
%setup -q -n %{srcname}-%{version}

%patch0 -p1
%patch2 -p1

%if 0%{?rhel} == 6
%patch100 -p1
%endif

cp %{SOURCE1} .

%build
%{__python} setup.py build

%install
%{__python} setup.py install --root=$RPM_BUILD_ROOT
mkdir -p $RPM_BUILD_ROOT/etc/ansible/
mkdir -p $RPM_BUILD_ROOT/etc/ansible/roles/
cp examples/hosts $RPM_BUILD_ROOT/etc/ansible/
cp examples/ansible.cfg $RPM_BUILD_ROOT/etc/ansible/
mkdir -p $RPM_BUILD_ROOT/%{_mandir}/man1
cp -v docs/man/man1/*.1 $RPM_BUILD_ROOT/%{_mandir}/man1/
mkdir -p $RPM_BUILD_ROOT/%{_datadir}/ansible
mkdir -p $RPM_BUILD_ROOT/%{_datadir}/ansible_plugins/{action,callback,connection,lookup,vars,filter}_plugins

%clean
rm -rf $RPM_BUILD_ROOT

%files
%defattr(-,root,root)
%{python_sitelib}/ansible*
%{_bindir}/ansible*
%config(noreplace) %{_sysconfdir}/ansible/
%doc README.md PKG-INFO CHANGELOG.md
%doc %{_mandir}/man1/ansible*
%license COPYING

%changelog
* Wed Apr 27 2016 Kevin Fenzi <kevin@scrye.com> - 1.9.6-2
- Remove version on Conflicts to allow:
- Fedora: dnf install --allowerasing ansible1.9
- RHEL/Centos: yum swap ansible ansible1.9
- Fixes bug #1330979

* Fri Apr 15 2016 Kevin Fenzi <kevin@scrye.com> - 1.9.6-1
- Update to 1.9.6. Fixes bug #1327744

* Sat Feb 13 2016 Toshio Kuratomi <toshio@fedoraproject.org> - 1.9.4-2
- Add three patches that were in the Fedora ansible package when it was based
  on 1.9.4 (fixes for dnf and docker)
- Use %%license tag

* Tue Feb  9 2016 Toshio Kuratomi <toshio@fedoraproject.org> - 1.9.4-1
- Initial Fedora build

